<?php

namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class IntegracaoTecfoodFactory {
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    /**
     * Retorna a URL de integração com o Tecfood.
     * 
     * @param mixed[] $params
     * 
     * @return mixed[]
     */
    public function getUrlIntegracaoTecfood(array $params) {
        $sql = "SELECT URLINTEGRACAOTECFOOD
                  FROM FCT_PARAMETROGERAL
                 WHERE NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Verifica se o contrato utiliza a integração com o FM.
     * 
     * @param mixed[] $params
     * 
     * @return mixed[]
     */
    public function verificarUtilizaIntegracao(array $params) {
        $sql = "SELECT IDINTEGRACAOTECFOOD
                  FROM FCT_CONTRATO
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna o tipo de local para integração dos locais de atendimento.
     * 
     * @param mixed[] $params
     * 
     * @return mixed[]
     */
    public function getTipoServicoIntegracaoTecfood(array $params) {
        $sql = "SELECT IDTIPOSERVINTTECFOOD
                  FROM FCT_CONTRATO
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    /**
     * Retorna os dados de local para integração dos locais de atendimento.
     * 
     * @param mixed[] $params
     * 
     * @return mixed[]
     */
    public function getDadosServicos(array $params) {
        $sql = "SELECT TO_CHAR(LPAD(FCT_SERVICOORCA.CDSERVORCA, 5,'0')) AS CDSERVORCA, FCT_SERVICOORCA.NMSERVORCA, FCT_SERVICOORCA.CDPRODFATSERV,
                       FCT_ITEMCONTRATO.CDGRUPSERVINTTECFOOD, FCT_ITEMCONTRATO.HRINIPREPSERVINTTECFOOD,
                       ESTRUTURAM.CDFILIAL, FCT_ITEMCONTRATO.NRITEMOCONTRATO, FCT_ITEMCONTRATO.NRSEQCONTRATO,
                       FCT_ITEMCONTRATO.NRESTRUTURAM
                  FROM FCT_SERVICOORCA
                  JOIN FCT_ITEMCONTRATO
                    ON FCT_SERVICOORCA.CDSERVORCA = FCT_ITEMCONTRATO.CDSERVORCA
                  JOIN ESTRUTURAM 
                    ON ESTRUTURAM.NRESTRUTURAM = FCT_ITEMCONTRATO.NRESTRUTURAM
                 WHERE FCT_ITEMCONTRATO.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND FCT_ITEMCONTRATO.NRORG = :NRORG
                   AND FCT_ITEMCONTRATO.NRESTRUTURAM IS NOT NULL";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function validaPadrServ() {
        $sql = "SELECT COUNT (*) VALIDA 
                  FROM PADRAOSERV";
        
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }

    public function getGrupServ() {
        $sql = "SELECT MIN(CDGRUPSERV) AS CDGRUPSERV 
                FROM GRUPSERV";
        
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }

    public function insereGrupServPadrao($params) {
        $sql = "INSERT INTO GRUPSERV (CDGRUPSERV, NMGRUPSERV, DTULTATUGRSV, NRORG, 
                                      DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, IDATIVO)
                   VALUES ('001', 'PADRAO', SYSDATE, :NRORG, 
                           SYSDATE, :NRORG, :CDOPERADOR, 'S')";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return '001';
    }


    public function validaExisteServico($params) {
        $sql = "SELECT COUNT(*) AS VALIDA
                  FROM SERVICO
                 WHERE CDFILIAL = :CDFILIAL
                   AND CDSERVFILI = :CDSERVFILI";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno =  $std->fetchAll();
        return $retorno[0]["VALIDA"];

    }

    public function insereServicos($params) {
        $sql = "INSERT INTO SERVICO (CDFILIAL, CDSERVFILI, NMSERVICO, CDGRUPSERV, HRINICATEN, 
                       CDPRODUTO, IDTIPOSERV, NRORG, DTINCLUSAO, CDOPERINCLUSAO, 
                       NRORGINCLUSAO, IDATIVO)
             VALUES  (:CDFILIAL, :CDSERVFILI, :NMSERVICO, :CDGRUPSERV, :HRINICATEN, 
                       :CDPRODUTO, :IDTIPOSERV, :NRORG, SYSDATE, :CDOPERADOR, 
                       :NRORG, 'S')";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }


    public function updataItensContrato(array $params) {
        $sql = "UPDATE FCT_ITEMCONTRATO
                   SET CDFILIALTECFOOD = :CDFILIALTECFOOD,
                       CDSERVFILITECFOOD = :CDSERVFILITECFOOD
                  WHERE NRITEMOCONTRATO = :NRITEMOCONTRATO
                    AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function getServicosInseridos(array $params) {
        $sql = "SELECT FCT_ITEMCONTRATO.NRSEQCONTRATO, FCT_ITEMCONTRATO.NRITEMOCONTRATO, FCT_ITEMCONTRATO.CDFILIALTECFOOD,
                       FCT_ITEMCONTRATO.NRESTRUTURAM, FCT_ITEMCONTRATO.CDSERVFILITECFOOD,CLIENTE.CDCLIENTE, FCT_ITNEGOCIACAOCONTRATO.VRTOTITEMCOMDESC
                  FROM FCT_ITEMCONTRATO
                  JOIN FCT_CONTRATO
                  ON FCT_CONTRATO.NRSEQCONTRATO = FCT_ITEMCONTRATO.NRSEQCONTRATO
                  JOIN FCT_ITNEGOCIACAOCONTRATO
                    ON FCT_ITNEGOCIACAOCONTRATO.NRITEMOCONTRATO =  FCT_ITEMCONTRATO.NRITEMOCONTRATO
                  JOIN CLIENTE 
                   ON CLIENTE.NRPARCNEGOCIO = FCT_CONTRATO.NRPARCNEGOCIO
                WHERE FCT_ITEMCONTRATO.NRSEQCONTRATO = :NRSEQCONTRATO
                  AND FCT_ITEMCONTRATO.NRORG = :NRORG
                  AND FCT_ITEMCONTRATO.CDFILIALTECFOOD IS NOT NULL";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function validaExisteClienFilial($params) {
        $sql = "SELECT COUNT(*) AS VALIDA
                  FROM CLIENFILIAL
                 WHERE CDCLIENTE = :CDCLIENTE
                   AND CDFILIAL = :CDFILIAL";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno =  $std->fetchAll();
        return $retorno[0]["VALIDA"];
    }
        
    public function insereClienFilial($params) {
        $sql = "INSERT INTO CLIENFILIAL (CDCLIENTE, CDFILIAL, NRORG, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO, IDATIVO)
                         VALUES (:CDCLIENTE, :CDFILIAL, :NRORG, SYSDATE, :CDOPERADOR, :NRORG, 'S')";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function validaExisteServClie($params) {
        $sql = "SELECT COUNT(*) AS VALIDA
                  FROM SERVCLIE
                 WHERE CDCLIENTE = :CDCLIENTE
                   AND CDFILIAL = :CDFILIAL
                   AND CDSERVFILI = :CDSERVFILI";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno =  $std->fetchAll();
        return $retorno[0]["VALIDA"];
    }

    public function insereServClie($params) {
        $sql = "INSERT INTO SERVCLIE (CDCLIENTE, CDFILIAL, CDSERVFILI, NRORG, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO, IDATIVO)
                         VALUES (:CDCLIENTE, :CDFILIAL, :CDSERVFILI, :NRORG, SYSDATE, :CDOPERADOR, :NRORG, 'S')";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function insereHistServFatu($params) {
        $sql = "INSERT INTO HISTSERVFATU (CDCLIENTE, CDFILIAL, CDSERVFILI, DTSRVFATUHIS, DTALTEFATHIS, VRSERVFATHIS,
                                          NRORG, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO, IDATIVO)
                    VALUES (:CDCLIENTE, :CDFILIAL, :CDSERVFILI, SYSDATE, SYSDATE, :VRSERVFATHIS,
                            :NRORG, SYSDATE, :CDOPERADOR, :NRORG, 'S')";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function insereLogIntegraTecfood($params) {
        $sql = "INSERT INTO FCT_LOGINTEGRATECFOOD (NRLOGINTEGRATECFOOD, NRSEQCONTRATO, NRITEMOCONTRATO, NRESTRUTURAM, DSETAPA,
                                   DSMOTIVO, NRORG, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO)
                     VALUES (:NRLOGINTEGRATECFOOD, :NRSEQCONTRATO, :NRITEMOCONTRATO, :NRESTRUTURAM, :DSETAPA,
                             :DSMOTIVO, :NRORG, 'S', SYSDATE, :NRORG, :CDOPERADOR)";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

}
?>
